// Licensed Materials - Property of IBM
// 5724-P68
// Copyright IBM Corporation 2005,2006,2007. All Rights Reserved.
// US Government Users Restricted Rights- Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

// Alcatel-Lucent 5620 SAM Pack

// SAMUBA_equipment_system_cpu.js - Metrics file for equipment.SystemCpuStats
//

//
//       i n i t _ e q u i p m e n t _ s y s t e m _ c p u _ s c h e m a
//....................................................................................
//
// define the csv file layout for SAM_equipment_system_cpu which handles equipment.SystemCpuStats records
//

var lastCpuTime = {};
// This is set here and used for the temperature "metrics"

function init_equipment_system_cpu_schema(context){

   context.schemas.add(
      PV.XMLInputSchema("SAM_equipment_system_cpu",
            {
		parseURI: parseSAMURI,
		precedence: 5,
                ignoreProcessingErrors: true,
		onOpen: function()
		     {
			// PV.adaptor.modelInterface = PV.ModelInterface()
		     },
                onClose: function()
			     {
				 PV.adaptor.modelInterface.commit()
			     }},
         PV.XMLRecordSchema( "SystemCpuStatsLogRecord", { xpath:XPathExp("equipment.SystemCpuStatsLogRecord"),
            onRead: function(rec) { schemaName = "SystemCpuStatsLogRecord"; process_equipment_SystemCpuStats(rec, PV.adaptor.modelInterface) }, maxOccurs: Infinity },


		PV.StringFieldSchema("systemCpuUsage", {xpath:XPathExp("systemCpuUsage")}),

		PV.StringFieldSchema("timeCaptured", {xpath:XPathExp("timeCaptured")}),
		PV.StringFieldSchema("periodicTime", {xpath:XPathExp("periodicTime")}),
		PV.StringFieldSchema("timeLogged", {xpath:XPathExp("timeLogged")}),
		PV.StringFieldSchema("monitoredObjectClass", {xpath:XPathExp("monitoredObjectClass")}),
		PV.StringFieldSchema("monitoredObjectPointer", {xpath:XPathExp("monitoredObjectPointer")}),
		PV.StringFieldSchema("displayedName", {xpath:XPathExp("displayedName")}),
		PV.StringFieldSchema("monitoredObjectSiteId", {xpath:XPathExp("monitoredObjectSiteId")}),
		PV.StringFieldSchema("monitoredObjectSiteName", {xpath:XPathExp("monitoredObjectSiteName")}),
		PV.StringFieldSchema("suspect", {xpath:XPathExp("suspect")}),
		PV.StringFieldSchema("createdOnPollType", {xpath:XPathExp("createdOnPollType")}),
		PV.StringFieldSchema("updatedOnPollType", {xpath:XPathExp("updatedOnPollType")}),
		PV.StringFieldSchema("deploymentState", {xpath:XPathExp("deploymentState")}),
		PV.StringFieldSchema("objectFullName", {xpath:XPathExp("objectFullName")}),
		PV.StringFieldSchema("name", {xpath:XPathExp("name")}),
		PV.StringFieldSchema("selfAlarmed", {xpath:XPathExp("selfAlarmed")})

						) // equipment.SystemCpuStatsLogRecord

					)  // XmlInputSchema

		     ) // this.schemas.add

} // initializeSchemas


//
//  Names of the csv columns that we need to extract
//


var equipmentSystemCpuMetrics = [ "systemCpuUsage"
								];


//
//   p r o c e s s _ e q u i p m e n t _ S y s t e m C p u S t a t s
//...............................................................................................
// funtion to loop over the name defined above and create a metric object for each entry
//

function process_equipment_SystemCpuStats(record, modelInterface)
{
    var theMetric;
    var myId;
    var timestamp;


    var monitoredObject = record.monitoredObjectPointer.toString();
    var monOb = new String(record.monitoredObjectPointer);
    var len = monOb.length;
    var elementName = monOb.substring(0,len-18);

    myId = PV.adaptor.schemas.idmap.idForName(elementName);
	if(myId == 0)
	{
		logP5Msg("process_equipment_SystemCpuStats", "SAMUBA_equipment_system_cpu", "Skipping 0 rid for --> "+ record.monitoredObjectPointer);
		return;
	}
    timestamp = Math.floor(record.timeCaptured/1000);

	// this is used to create a timestamp for the HW environment temperatures
	if (isDef(record.monitoredObjectSiteId)) {
		lastCpuTime[record.monitoredObjectSiteId] = timestamp;
		}


	logP4Msg("process_equipment_SystemCpuStats", "SAMUBA_equipment_system_cpu", "ENTERING for --> "+ elementName + " with id == " + myId);
    for(var i = 0; i < equipmentSystemCpuMetrics.length; i++)
	{
	    theMetric = modelInterface.FloatMetric();
	    theMetric.name = "AP~Specific~Alcatel~5620 SAM~Bulk~equipment~SystemCpuStats~" + equipmentSystemCpuMetrics[i];
	    theMetric.rid = myId;
	    theMetric.timestamp = timestamp;
	    theMetric.value = record[equipmentSystemCpuMetrics[i]];
	    modelInterface.addMetric(theMetric);
	}
	logP4Msg("process_equipment_SystemCpuStats", "SAMUBA_equipment_system_cpu", "LEAVING");
}

