// Licensed Materials - Property of IBM
// 5724-P68
// Copyright IBM Corporation 2005,2006,2007. All Rights Reserved.
// US Government Users Restricted Rights- Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

// Alcatel-Lucent 5620 SAM Pack

// SAMUBA_equipment_hw_environment.js - Processes the inventory of equipment.HwEnvironment as metrics
//

//
//       i n i t _ e q u i p m e n t _ s y s t e m _ m e m o r y _ s c h e m a
//....................................................................................
//
// define the XML file layout for SAM_equipment_hw_environment which handles equipment.HwEnvironment
//


function init_equipment_hw_environment_schema(context){

   context.schemas.add(
      PV.XMLInputSchema("SAM_equipment_hw_environment",
            {
		parseURI: parseSAMURI,
		precedence: 4,
                ignoreProcessingErrors: true,
		onOpen: function()
		     {
			// PV.adaptor.modelInterface = PV.ModelInterface()
		     },
                onClose: function()
			     {
				 PV.adaptor.modelInterface.commit()
			     }},
         PV.XMLRecordSchema( "HwEnvironment", { xpath:XPathExp("equipment.HwEnvironment"),
            onRead: function(rec) { schemaName = "HwEnvironment"; process_equipment_hw_environment_stats(rec, PV.adaptor.modelInterface) }, maxOccurs: Infinity },


		PV.StringFieldSchema("siteId", {xpath:XPathExp("siteId")}),
		PV.StringFieldSchema("siteName", {xpath:XPathExp("siteName")}),
		PV.StringFieldSchema("slotId", {xpath:XPathExp("slotId")}),
		PV.StringFieldSchema("daughterCardSlotId", {xpath:XPathExp("daughterCardSlotId")}),
		PV.StringFieldSchema("containingParentName", {xpath:XPathExp("containingParentName")}),
		PV.StringFieldSchema("identifier", {xpath:XPathExp("identifier")}),
		PV.StringFieldSchema("shelfId", {xpath:XPathExp("shelfId")}),
		PV.StringFieldSchema("hwIndex", {xpath:XPathExp("hwIndex")}),
		PV.StringFieldSchema("temperature", {xpath:XPathExp("temperature")}),
		PV.StringFieldSchema("temperatureInFahrenheit", {xpath:XPathExp("temperatureInFahrenheit")}),
		PV.StringFieldSchema("temperatureThreshold", {xpath:XPathExp("temperatureThreshold")}),
		PV.StringFieldSchema("temperatureThresholdInFahrenheit", {xpath:XPathExp("temperatureThresholdInFahrenheit")}),
		PV.StringFieldSchema("temperatureThresholdCrossed", {xpath:XPathExp("temperatureThresholdCrossed")}),
		PV.StringFieldSchema("deploymentState", {xpath:XPathExp("deploymentState")}),
		PV.StringFieldSchema("objectFullName", {xpath:XPathExp("objectFullName")}),
		PV.StringFieldSchema("name", {xpath:XPathExp("name")}),
		PV.StringFieldSchema("selfAlarmed", {xpath:XPathExp("selfAlarmed")})

						) // equipment.HwEnvironment

					)  // XmlInputSchema

		     ) // this.schemas.add

} // initializeSchemas



//
//  Names of the csv columns that we need to extract
//


var equipmentHwEnvironmentPseudoMetrics = [ "temperature",
					"temperatureInFahrenheit",
					"temperatureThreshold",
					"temperatureThresholdInFahrenheit"
				  				   ];


//
//   p r o c e s s _ e q u i p m e n t _ H w E n v i r o n m e n t
//...............................................................................................
// function to loop over the name defined above and create a metric object for each entry
//

function process_equipment_hw_environment_stats(record, modelInterface)
{
    var theMetric;
    var myId;
    var timestamp;

//    var monitoredObject = record.monitoredObjectPointer.toString();
//    var monOb = (new String(record.monitoredObjectPointer));
//    var len = monOb.length;
//    var elementName = monOb.substring(0,len-18);

//    myId = PV.adaptor.schemas.idmap.idForName(elementName);


	logP4Msg("process_equipment_hw_environment_stats", "SAMUBA_equipment_hw_environment_stats", "ENTERING");

//	PV.halt();

    myId = PV.adaptor.schemas.idmap.idForName(record.objectFullName.toString());
	logP4Msg("process_equipment_hw_environment_stats", "SAMUBA_equipment_hw_environment_stats", "After myid");
	if(myId == 0)
	{
		logP4Msg("process_equipment_hw_environment_stats", "SAMUBA_equipment_hw_environment_stats", "Skipping 0 rid for --> "+ record.objectFullName);
		return;
	}

	//		logP4Msg("process_equipment_hw_environment_stats", "SAMUBA_equipment_hw_environment_stats", "before timestamp");

    timestamp = lastCpuTime[record.siteId];

    //		logP4Msg("process_equipment_hw_environment_stats", "SAMUBA_equipment_hw_environment_stats", "before isdef");

	if (isDef(timestamp)) {
	    //		logP4Msg("process_equipment_hw_environment_stats", "SAMUBA_equipment_hw_environment_stats", "before current");

	    current = modelInterface.currentDate;
	    //		logP4Msg("process_equipment_hw_environment_stats", "SAMUBA_equipment_hw_environment_stats", "before age");
	    age = current-timestamp;

	    //		logP4Msg("process_equipment_hw_environment_stats", "SAMUBA_equipment_hw_environment_stats", "curr:"+current+" last:"+timestamp+" age:"+age);

	if (age < 5400) {

	// Process these metrics only if the last CPU metric processed was less than 1.5 hours old.
	// Because the temperature data is basically current, and if we are processing old data,
	// then it is really wrong to be putting the current temperature values in for that date.

	    //	logP4Msg("process_equipment_hw_environment_stats", "SAMUBA_equipment_hw_environment_stats", "ENTERING for --> "+ record.objectFullName + " with id == " + myId);
    for(var i = 0; i < equipmentHwEnvironmentPseudoMetrics.length; i++)
	{

	    theMetric = modelInterface.FloatMetric();
	    theMetric.name = "AP~Specific~Alcatel~5620 SAM~Bulk~equipment~HwEnvironment~" + equipmentHwEnvironmentPseudoMetrics[i];
	    theMetric.rid = myId;
	    theMetric.timestamp = timestamp;
	    theMetric.value = record[equipmentHwEnvironmentPseudoMetrics[i]];
	    modelInterface.addMetric(theMetric);

	    //	    logP4Msg("process_equipment_hw_environment_stats", "SAMUBA_equipment_hw_environment_stats", "Adding  metric:" + theMetric.name + " Value: " + record[equipmentHwEnvironmentPseudoMetrics[i]]);


	} // for
	} // age
	else {
		logP4Msg("process_equipment_hw_environment_stats", "SAMUBA_equipment_hw_environment_stats", "Skipping metrics, too old: curr:"+current+" last:"+timestamp+" age:"+age);
		}
		

	} // ifdef timestamp


	logP4Msg("process_equipment_hw_environment_stats", "SAMUBA_equipment_hw_environment_stats", "LEAVING");

}
